﻿using DataSharing.RawData;
using DotNetCore.CAP;
using Hotline.Share.Requests;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using SqlSugar;
using XF.Domain.Repository;

namespace DataSharing.Host.Controllers
{
    public class HotlineWebController : BaseController
    {
        private readonly IMapper _mapper;
        private readonly IMediator _mediator;
        private readonly ICapPublisher _capPublisher;
        private readonly IRepository<DsOrder> _dsOrderRepository;
        private readonly IRepository<DsTelCall> _dsTelCallRepository;

        public HotlineWebController(IMapper mapper,
            IMediator mediator,
            ICapPublisher capPublisher,
            IRepository<DsOrder> dsOrderRepository,
            IRepository<DsTelCall> dsTelCallRepository)
        {
            _mapper = mapper;
            _mediator = mediator;
            _capPublisher = capPublisher;
            _dsOrderRepository = dsOrderRepository;
            _dsTelCallRepository = dsTelCallRepository;
        }


        [HttpPost("getorderlist")]
        [AllowAnonymous]
        public async Task<object> GetOrderlist(DateTime StartDate, DateTime EndDate)
        {
            EndDate = EndDate.AddDays(1).AddSeconds(-1);

            return await _dsOrderRepository.Queryable()
                .Where(p => p.LastSendProvinceTime >= StartDate && p.LastSendProvinceTime <= EndDate)
                .Where(p => p.FirstSendProvinceTime.HasValue)
                .Where(p => SqlFunc.DateDiff(DateType.Second, p.StartTime.Value, p.FirstSendProvinceTime.Value) > 180)
                .ToListAsync();

        }

        [HttpPost("getcalllist")]
        [AllowAnonymous]
        public async Task<object> GetCalllist(DateTime StartDate, DateTime EndDate)
        {
            EndDate = EndDate.AddDays(1).AddSeconds(-1);

            return await _dsTelCallRepository.Queryable()
                .Where(p => p.LastSendProvinceTime >= StartDate && p.LastSendProvinceTime <= EndDate)
                .Where(p => p.FirstSendProvinceTime.HasValue)
                .Where(p => SqlFunc.DateDiff(DateType.Second, p.OverTime.Value, p.FirstSendProvinceTime.Value) > 180)
                .ToListAsync();

        }
    }
}
